Revisionair v0.13.4 Revisionair.Storage.Agent View Source

A simple implementation of the Revisionair.Storage protocol that builds on the Agent module.

This is thus a very ephemeral persistence layer, which, though paradoxical and maybe not very practical in real-life applications, is at least very useful as a simple example and for testing.

Link to this section Summary

Link to this section Functions

Link to this function

delete_all_revisions_of(item_type, item_id, opts)

Callback implementation for Revisionair.Storage.delete_all_revisions_of/3.

Link to this function

get_revision(item_type, item_id, revision, opts)

Callback implementation for Revisionair.Storage.get_revision/4.

Link to this function

list_revisions(item_type, item_id, opts)

Callback implementation for Revisionair.Storage.list_revisions/3.

Link to this function

newest_revision(item_type, item_id, opts)

Callback implementation for Revisionair.Storage.newest_revision/3.

Link to this function

store_revision(structure, item_type, item_id, metadata, opts)

Callback implementation for Revisionair.Storage.store_revision/5.